.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.06",
.\"     date            = "24 October 1997",
.\"     time            = "22:52:23 MDT",
.\"     filename        = "man2html.man",
.\"     address         = "Center for Scientific Computing
.\"                        University of Utah
.\"                        Department of Mathematics, 105 JWB
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "27560 221 936 6862",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@ieee.org (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "UNIX manual page, HTML",
.\"     supported       = "yes",
.\"     docstring       = "This is the UNIX manual page documentation
.\"                        man2html, a converter of UNIX manual page
.\"                        files to strictly-grammar-conforming HTML.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH MAN2HTML 1 "24 October 1997" "Version 1.06"
.\"======================================================================
.SH NAME
man2html \- convert a UNIX manual page file from nroff/troff -man format to HTML
.\"======================================================================
.SH SYNOPSIS
.B man2html
[
.B "\-v"
.I "HTML=[2|3|3.2]"
]
.if n .ti +9n
[
.I input-manpage-file(s)
or
.if n .ti +9n
.RI "< " input-manpage-file  " > " output-html-file
]
.\"======================================================================
.SH DESCRIPTION
.B man2html
converts UNIX manual page files named on the command line, or
provided on
.IR stdin ,
from
.BR nroff (1)/ troff (1)
.I \-man
format to strictly-grammar-conforming HTML.
.PP
When input filenames are given, the output files
have the same base name, but with extension
.IR ".html" .
.PP
You can verify the correctness of the translation
by validating the output HTML file with either
.BR html-check (1)
or
.BR html-ncheck (1);
neither should produce any warnings or errors whatsoever.
.PP
Little attempt is made to prettyprint the output HTML; that
job is better left to a separate program,
.BR html-pretty (1).
.PP
Although some vendors, such as Sun Microsystems,
provide clear documentation of how manual pages
should be written, many manual page authors ignore
those recommendations, and use arbitrary
.RB [ nt ] roff
markup to achieve the traditional appearance of
UNIX manual pages, without actually using the
standard
.I \-man
format commands.
.PP
.B man2html
works quite well on Sun manual pages, but may be
less successful on manual pages from other
sources.  In such a case, an alternative may be to
use T. A. Phelp's
.BR RosettaMan (1),
commonly installed as
.BR rman (1).
That program works on the
.I output
of
.BR nroff (1),
and attempts to guess manual page structure from
the horizontal and vertical spacing in order to
add HTML markup.  When vendor-provided manual
pages are available only in preformatted form, as
on IBM AIX and SGI IRIX systems,
.BR rman (1)
may be your only choice.  However, when
.B man2html
can be used successfully, it can often do a better
job than
.BR rman (1)
because it has a better understanding of the
document structure implied
.RB [ nt ] roff
manual-page markup.
.\"======================================================================
.SH OPTIONS
There is only one option:
.TP \w'\fB\-v_HTML=[2|3|3.2]\fP'u+3n
.BI \-v " HTML=[2|3|3.2]"
Define the HTML grammar level to be used for the
output
.RS
.nf
\fC<!DOCTYPE HTML PUBLIC ".\|.\|.">\fP
.fi
.RE
.IP
declaration.  The default, if this option is
omitted, is
.BI \-v " HTML=2,"
to select grammar level 2, which is
reasonably-well supported by all current browsers.
.\"======================================================================
.SH "HTML GRAMMAR LEVELS"
The level 3 grammar has expired; some of its
features, particularly the support for markup of
mathematics, will appear in a future HTML grammar
level.
.PP
The version 3.2 grammar is a stopgap, which,
despite its higher number, lies approximately
between 2 and 3 in features.  It was released on
5-Nov-1996 at \&\fChttp://www.w3.org/pub/WWW/\fP
in order to provide a stable grammar toward which
WWW browser developers could work.
.PP
There are only four potential differences in the
output of
.B man2html
for these grammar levels:
.RS
.TP \w'\(bu'u+3n
\(bu
The output \fC<!DOCTYPE HTML PUBLIC ".\|.\|.">\fP
declaration depends on the grammar level.
.TP
\(bu
At version 3 and above, the SGML entity
.I "&nbsp;"
can be used for non-breakable space instead of the
less obvious numeric entity
.I "&#160;"
which is required by the level 2 grammar.
.TP
\(bu
At version 3.2, the SGML entity
.IR "&quot;" ,
representing a quotation mark, must be replaced by
a numeric entity,
.IR "&#34;" ,
because of an unfortunate error of omission in the
grammar.
.TP
\(bu
At version 3.2, the output HTML will use
.I "<CENTER> \|.\|.\|. </CENTER>"
directives to support centered text.  At earlier
grammar levels, centering requests are ignored,
but lines are still broken as they would be when
centered.
.PP
Centering is exceedingly rare in manual page files
(it is completely absent from
.I all
of Sun's standard manual pages), so the default
level 2 grammar should almost always be
sufficient.
.RE
.\"======================================================================
.SH "SEE ALSO"
.BR html-check (1),
.BR html-ncheck (1),
.BR html-norm (1),
.BR html-pretty (1),
.BR html-spam (1),
.BR htmlchek (1),
.BR nsgmls (1),
.BR rman (1),
.BR RosettaMan (1),
.BR sgmlnorm (1),
.BR sgmls (1),
.BR spam (1),
.BR spent (1),
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe
Center for Scientific Computing
University of Utah
Department of Mathematics, 105 JWB
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
USA
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP, \fCbeebe@ieee.org\fP (Internet)
WWW URL: \fChttp://www.math.utah.edu/~beebe\fP
Tel: +1 801 581 5254
FAX: +1 801 581 4148
.fi
.\"==============================[The End]==============================
